varsityblues: varsityblues: Writing your UofT assignments and thesis using...

varsitybluesR Documentation

varsityblues: Writing your UofT assignments and thesis using Quarto

Description

This package aims to encourage reproducible research and better reproducibility practices using simple Markdown syntax while embedding all of the R code to produce plots and analyses as well.

Author(s)

Maintainer: Mauricio Vargas m.sepulveda@mail.utoronto.ca (ORCID) [copyright holder]


pachadotdev/varsityblues documentation built on March 25, 2024, 1:57 p.m.