| varsityblues | R Documentation |
This package aims to encourage reproducible research and better reproducibility practices using simple Markdown syntax while embedding all of the R code to produce plots and analyses as well.
Maintainer: Mauricio Vargas m.sepulveda@mail.utoronto.ca (ORCID) [copyright holder]
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.